@@ -24,7 +24,7 @@ def submit(job_text):
         else:
             print('Done, submitting a new job!')
             # my_env = os.environ.copy()
-            sp.run(job_text)
+            sp.run(job_text, shell=True)
             time.sleep(120)
             sys.exit(0)
         time.sleep(1)
